widen_flat_table: widen_flat_table
Description
Makes the pk fields the primary key of the table. The rest of the fields that
prevent them from being so, are extracted to another table. The original
table is widened by combining the extracted fields with the measures.
Usage
widen_flat_table(ft, pk, measures)
Value
A list of tibble objects.
Arguments
- ft
A tibble object.
- pk
A vector of names.
- measures
A vector of names.